﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Silanis.ESL.SDK;
using Silanis.ESL.SDK.Builder;
using System.IO;

namespace customFields
{
    class customFields
    {
        public static string email1 = "esl.signer1@example.com";
        public static string email2 = "esl.signer2@example.com";
        public static string API_KEY = "your_api_key_here";
        public static string API_URL = "https://sandbox.e-signlive.com/api";

        public static void Main(string[] args)
        {

            EslClient eslClient = new EslClient(API_KEY, API_URL);

            //PDF to create package
            FileStream fs = File.OpenRead(@"DOC_FILE_PATH");

            // First custom field
            String customFieldId1 = "policy_number_id";
            CustomField customField = CustomFieldBuilder.CustomFieldWithId(customFieldId1)
                                    .WithDefaultValue("123-456-789-0")
                                    .WithTranslation(TranslationBuilder.NewTranslation("en")
                                            .WithName("Policy Number")
                                            .WithDescription("Car Insurance Policy Number."))
                                    .Build();

            eslClient.GetCustomFieldService().CreateCustomField(customField);

            // Second custom field
            String customFieldId2 = "agent_number_id";
            CustomField customField2 = eslClient.GetCustomFieldService()
                    .CreateCustomField(CustomFieldBuilder.CustomFieldWithId(customFieldId2)
                                    .WithDefaultValue("0-987-654-321")
                                    .WithTranslation(TranslationBuilder.NewTranslation("en")
                                            .WithName("Agent Number")
                                            .WithDescription("Employee Agent Number."))
                                    .Build()
                    );


            // Create and send package with two custom fields
            DocumentPackage superDuperPackage = PackageBuilder.NewPackageNamed("Sample Insurance policy")
                    .WithSigner(SignerBuilder.NewSignerWithEmail(email1)
                            .WithFirstName("John")
                            .WithLastName("Smith")
                            .WithCustomId("Signer1"))
                    .WithSigner(SignerBuilder.NewSignerWithEmail(email2)
                            .WithFirstName("Mary")
                            .WithLastName("Doe")
                            .WithCustomId("Signer2"))
                    .WithDocument(DocumentBuilder.NewDocumentNamed("Sample Contract")
                                    .FromStream(fs, DocumentType.PDF)
                                    .EnableExtraction()
                                    .WithSignature(SignatureBuilder.SignatureFor(email1)
                                            .WithPositionAnchor(TextAnchorBuilder.NewTextAnchor("Client Signature")
                                                    .AtPosition(TextAnchorPosition.TOPLEFT)
                                                    .WithOccurrence(0)
                                                    .WithCharacter(16)
                                                    .WithSize(250, 70)
                                                    .WithOffset(20, -58))
                                            .WithField(FieldBuilder.CustomField(customField.Id)
                                                    .WithPositionAnchor(TextAnchorBuilder.NewTextAnchor("Policy Number")
                                                            .AtPosition(TextAnchorPosition.TOPLEFT)
                                                            .WithOccurrence(0)
                                                            .WithCharacter(13)
                                                            .WithSize(250, 25)
                                                            .WithOffset(20, -10))
                                                    ))
                                    .WithSignature(SignatureBuilder.SignatureFor(email2)
                                            .WithPositionAnchor(TextAnchorBuilder.NewTextAnchor("Manager Signature")
                                                    .AtPosition(TextAnchorPosition.TOPLEFT)
                                                    .WithOccurrence(0)
                                                    .WithCharacter(17)
                                                    .WithSize(250, 70)
                                                    .WithOffset(20, -58))
                                            .WithField(FieldBuilder.CustomField(customField2.Id)
                                                    .AtPosition(50, 50)
                                                    .OnPage(0)
                                                    ))
                    )
                    .Build();

            PackageId packageId = eslClient.CreatePackage(superDuperPackage);

            DocumentPackage retrievedPackage = eslClient.GetPackage(packageId);

            // Get the entire list of custom field from account
            IList<CustomField> retrieveCustomFieldList1 = eslClient.GetCustomFieldService().GetCustomFields(Direction.ASCENDING);

            // Get the first custom field from account
            CustomField retrieveCustomField = eslClient.GetCustomFieldService().GetCustomField(customFieldId1);

            // Delete the second custom field from account
            eslClient.GetCustomFieldService().DeleteCustomField(customFieldId2);
        }
    }
}
